@@ -1,16 +1,17 @@
 #
 # This file is part of Config-Model-OpenSsh
 #
-# This software is Copyright (c) 2013 by Dominique Dumont.
+# This software is Copyright (c) 2014 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::OpenSsh ;
-{
-  $Config::Model::Backend::OpenSsh::VERSION = '1.232';
-}
+$Config::Model::Backend::OpenSsh::VERSION = '1.236';
+use 5.10.1;
+
+use Config::Model 2.050;
 
 use Mouse ;
 extends "Config::Model::Backend::Any" ;
@@ -24,7 +25,7 @@ has 'current_node'  => (
 
 use Carp ;
 use IO::File ;
-use Log::Log4perl;
+use Log::Log4perl 1.11;
 use File::Copy ;
 use File::Path ;
 
@@ -72,7 +73,7 @@ sub read {
             my ( $regexp, $sub ) = @dispatch[ $i++, $i++ ];
             if ( $k =~ $regexp and $self->can($sub)) {
                 $logger->trace("read_ssh_file: dispatch calls $sub");
-                $self->$sub( $config_root, $k, \@v, $comment );
+                $self->$sub( $config_root, $k, \@v, $comment, $args{check} );
                 last;
             }
 
@@ -103,13 +104,24 @@ sub ssh_write {
 }
 
 sub assign {
-    my ($self,$root, $raw_key,$arg,$comment) = @_ ;
+    my ($self,$root, $raw_key,$arg,$comment, $check) = @_ ;
     $logger->debug("assign: $raw_key @$arg # $comment");
 
 
     # keys are case insensitive, try to find a match
     my $key = $self->current_node->find_element ($raw_key, case => 'any') ;
 
+    if (not defined $key) {
+        if ($check eq 'yes') {
+            # drop if -force is not set
+            die "Error: unknown parameter: '$raw_key'. Use -force option to drop this parameter\n";
+        }
+        else {
+            say "Dropping parameter '$raw_key'" ;
+        }
+        return;
+    }
+
     my $elt = $self->current_node->fetch_element($key) ;
     my $type = $elt->get_type;
     #print "got $key type $type and ",join('+',@$arg),"\n";
@@ -170,7 +182,7 @@ sub write_node_content {
     my $result = '' ;
     my $match  = '' ;
 
-    foreach my $name ($node->get_element_name(for => 'master') ) {
+    foreach my $name ($node->get_element_name() ) {
 	next unless $node->is_element_defined($name) ;
 	my $elt = $node->fetch_element($name) ;
 	my $type = $elt->get_type;
@@ -221,10 +233,22 @@ no Mouse;
 
 1;
 
+# ABSTRACT: Common backend methods for Ssh and Sshd backends
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Config::Model::Backend::OpenSsh - Common backend methods for Ssh and Sshd backends
 
+=head1 VERSION
+
+version 1.236
+
 =head1 SYNOPSIS
 
 None. Inherited by L<Config::Model::Backend::OpenSsh::Ssh> and
@@ -235,10 +259,20 @@ L<Config::Model::Backend::OpenSsh::Sshd>.
 Methods used by both L<Config::Model::Backend::OpenSsh::Ssh> and
 L<Config::Model::Backend::OpenSsh::Sshd>. 
 
-=head1 AUTHOR
-
-Dominique Dumont, (ddumont at cpan dot org)
-
 =head1 SEE ALSO
 
 L<cme>, L<Config::Model>, L<Config::Model::OpenSsh>
+
+=head1 AUTHOR
+
+Dominique Dumont
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2014 by Dominique Dumont.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 2.1, February 1999
+
+=cut
