@@ -1,17 +1,14 @@
 #
 # This file is part of Config-Model-OpenSsh
 #
-# This software is Copyright (c) 2013 by Dominique Dumont.
+# This software is Copyright (c) 2014 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::OpenSsh::Ssh ;
-{
-  $Config::Model::Backend::OpenSsh::Ssh::VERSION = '1.232';
-}
-
+$Config::Model::Backend::OpenSsh::Ssh::VERSION = '1.236';
 use Mouse ;
 use 5.10.1;
 extends "Config::Model::Backend::OpenSsh" ;
@@ -114,7 +111,7 @@ sub write_forward {
     my $sep = $v6 ? '/' : ':';
 
     my $line = '';
-    foreach my $name ($forward_elt->get_element_name(for => 'master') ) {
+    foreach my $name ($forward_elt->get_element_name() ) {
 	next if $name eq 'ipv6' ;
 	my $elt = $forward_elt->fetch_element($name) ;
 	my $v = $elt->fetch($mode) ;
@@ -130,12 +127,22 @@ sub write_forward {
 
 no Mouse;
 
+# ABSTRACT: Backend for ssh configuration files
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Config::Model::Backend::OpenSsh::Ssh - Backend for ssh configuration files
 
+=head1 VERSION
+
+version 1.236
+
 =head1 SYNOPSIS
 
 None
@@ -166,10 +173,20 @@ C<ssh_root> configuration tree.
 Write F<ssh_config> in C<config_dir> from the data stored in  
 C<ssh_root> configuration tree.
 
-=head1 AUTHOR
-
-Dominique Dumont, (ddumont at cpan dot org)
-
 =head1 SEE ALSO
 
 L<cme>, L<Config::Model>, L<Config::Model::OpenSsh>
+
+=head1 AUTHOR
+
+Dominique Dumont
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2014 by Dominique Dumont.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 2.1, February 1999
+
+=cut
